Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-10-14 Thread Roger Quadros
Kishon,

On 10/14/2013 12:19 PM, Kishon Vijay Abraham I wrote:
> Hi Roger,
> 
> On Friday 11 October 2013 08:32 PM, Roger Quadros wrote:
>> On 09/16/2013 10:37 AM, Roger Quadros wrote:
>>> On 09/16/2013 06:01 AM, Kishon Vijay Abraham I wrote:
 On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:
> Hi Kishon,
>
> On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:

>>   #ifdef CONFIG_OF
>> -static const struct of_device_id omap_usb3_id_table[] = {
>> +static const struct of_device_id omap_pipe3_id_table[] = {
>> +{ .compatible = "ti,omap-pipe3" },
>
> why do you need "omap-pipe3", isn't sata, pcie and usb3 sufficient?

 I thought it would be better if everyone uses omap-pipe3 and added pcie, 
 sata if there are any specific settings (for pcie or sata) that should be 
 done.
>>>
>>> We can always add specialized options later when needed. AFAIK just the
>>> DPLL data is different among the different PHYs.
>
>> +{ .compatible = "ti,omap-sata" },
>> +{ .compatible = "ti,omap-pcie" },
>>   { .compatible = "ti,omap-usb3" },
>>>
>>> I think compatible strings should be improved to indicate that it is a PHY.
>>>
>>> e.g. "ti,omap-phy-sata" or just "ti,pipe3-phy-sata"
>>>
>>
>> Please remove "ti,omap-pcie" for now, you can add it later whenever you add
>> dpll settings for pcie.
>>
>> Also, please change the newly added compatible strings to
>>
>> "ti,phy-pipe3-usb3" and "ti,phy-pipe3-sata"
> 
> No, I think we should have omap in the compatible since this PHY is specific 
> to
> OMAP.

DRA7x and an am43x are not OMAP so I was suggesting not to use it for new PHY 
types.
We still preserve just "ti,omap-usb3" for backward compatibility.

cheers,
-roger

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-10-14 Thread Kishon Vijay Abraham I
Hi Roger,

On Friday 11 October 2013 08:32 PM, Roger Quadros wrote:
> On 09/16/2013 10:37 AM, Roger Quadros wrote:
>> On 09/16/2013 06:01 AM, Kishon Vijay Abraham I wrote:
>>> On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:
 Hi Kishon,

 On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:
> Adapted omap-usb3 PHY driver to Generic PHY Framework and moved 
> phy-omap-usb3
> driver in drivers/usb/phy to drivers/phy and also renamed the file to
> phy-omap-pipe3 since this same driver will be used for SATA PHY and
> PCIE PHY.

 I would suggest to split the renaming and PHY adaptation into 2 separate 
 patches.
>>>
>>> Alright.

>
> Signed-off-by: Kishon Vijay Abraham I 
> ---
>   Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
>   drivers/phy/Kconfig|   10 +
>   drivers/phy/Makefile   |1 +
>   .../phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c}   |  206 
> +++-

 how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as 
 non-OMAP e.g. DRA7.
>>>
>>> hmm.. I thought it would be consistent with other PHY drivers 
>>> (phy-omap-usb2). Moreover DRA7 is OMAP based platform ;-) Maybe we should 
>>> reserve that for later?
>>
>> OK. Up to you.
>>

>   drivers/usb/phy/Kconfig|   11 --
>   drivers/usb/phy/Makefile   |1 -
>   include/linux/phy/omap_pipe3.h |   52 +
>   7 files changed, 177 insertions(+), 109 deletions(-)
>   rename drivers/{usb/phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c} (57%)
>   create mode 100644 include/linux/phy/omap_pipe3.h
>
> diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
> b/Documentation/devicetree/bindings/usb/usb-phy.txt
> index c0245c8..36bdb17 100644
> --- a/Documentation/devicetree/bindings/usb/usb-phy.txt
> +++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
> @@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
>   #phy-cells = <0>;
>   };
>
> -OMAP USB3 PHY
> +OMAP PIPE3 PHY
>
>   Required properties:
> - - compatible: Should be "ti,omap-usb3"
> + - compatible: Should be "ti,omap-usb3", "ti,omap-pipe3", "ti,omap-sata"
> +   or "ti,omap-pcie"
>- reg : Address and length of the register set for the device.
>- reg-names: The names of the register addresses corresponding to the 
> registers
>  filled in "reg".
> diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
> index ac239ac..5c2e7a0 100644
> --- a/drivers/phy/Kconfig
> +++ b/drivers/phy/Kconfig
> @@ -27,6 +27,16 @@ config OMAP_USB2
> The USB OTG controller communicates with the comparator using this
> driver.
>
> +config OMAP_PIPE3
> +tristate "OMAP PIPE3 PHY Driver"
> +select GENERIC_PHY
> +select OMAP_CONTROL_USB
 how about
 depends on OMAP_CONTROL_USB
>>>
>>> From whatever I could make out from comments of Greg in my Generic PHY 
>>> Framework, it's better to do a select of dependent modules instead of 
>>> depends on.
>>
>> You can use select, provided the item you are selecting doesn't depend on 
>> anything else.
>> As OMAP_CONTROL_USB depends on ARCH_OMAP2PLUS, your configuration will fail 
>> if a user enables
>> OMAP_PIPE3 on non OMAP configuration.
>>
>> Further, in this case since it is OMAP related driver, there is no point in 
>> showing/building it
>> if OMAP platform is not selected, so you at least need [depends on 
>> "ARCH_OMAP2PLUS"] to fix
>> both issue I mentioned.
>>

 Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.

> +help
> +  Enable this to support the PIPE3 PHY that is part of SOC. This

 worth mentioning TI OMAP/DRA SoCs.
>>>
>>> right.

> +  driver takes care of all the PHY functionality apart from 
> comparator.
> +  This driver interacts with the "OMAP Control PHY Driver" to power
> +  on/off the PHY.
> +
>   config TWL4030_USB
>   tristate "TWL4030 USB Transceiver Driver"
>   depends on TWL4030_CORE && REGULATOR_TWL4030 && USB_MUSB_OMAP2PLUS
> diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
> index 0dd8a98..48bf9f2 100644
> --- a/drivers/phy/Makefile
> +++ b/drivers/phy/Makefile
> @@ -4,4 +4,5 @@
>
>   obj-$(CONFIG_GENERIC_PHY)+= phy-core.o
>   obj-$(CONFIG_OMAP_USB2)+= phy-omap-usb2.o
> +obj-$(CONFIG_OMAP_PIPE3)+= phy-omap-pipe3.o
>   obj-$(CONFIG_TWL4030_USB)+= phy-twl4030-usb.o
> diff --git a/drivers/usb/phy/phy-omap-usb3.c 
> b/drivers/phy/phy-omap-pipe3.c
> similarity index 57%
> rename from drivers/usb/phy/phy-omap-usb3.c
> rename to drivers/phy/phy-omap-pipe3.c
> index 4004f82..ee9a901 100644

Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-10-14 Thread Kishon Vijay Abraham I
Hi Roger,

On Friday 11 October 2013 08:32 PM, Roger Quadros wrote:
 On 09/16/2013 10:37 AM, Roger Quadros wrote:
 On 09/16/2013 06:01 AM, Kishon Vijay Abraham I wrote:
 On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:
 Hi Kishon,

 On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:
 Adapted omap-usb3 PHY driver to Generic PHY Framework and moved 
 phy-omap-usb3
 driver in drivers/usb/phy to drivers/phy and also renamed the file to
 phy-omap-pipe3 since this same driver will be used for SATA PHY and
 PCIE PHY.

 I would suggest to split the renaming and PHY adaptation into 2 separate 
 patches.

 Alright.


 Signed-off-by: Kishon Vijay Abraham I kis...@ti.com
 ---
   Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
   drivers/phy/Kconfig|   10 +
   drivers/phy/Makefile   |1 +
   .../phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c}   |  206 
 +++-

 how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as 
 non-OMAP e.g. DRA7.

 hmm.. I thought it would be consistent with other PHY drivers 
 (phy-omap-usb2). Moreover DRA7 is OMAP based platform ;-) Maybe we should 
 reserve that for later?

 OK. Up to you.


   drivers/usb/phy/Kconfig|   11 --
   drivers/usb/phy/Makefile   |1 -
   include/linux/phy/omap_pipe3.h |   52 +
   7 files changed, 177 insertions(+), 109 deletions(-)
   rename drivers/{usb/phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c} (57%)
   create mode 100644 include/linux/phy/omap_pipe3.h

 diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
 b/Documentation/devicetree/bindings/usb/usb-phy.txt
 index c0245c8..36bdb17 100644
 --- a/Documentation/devicetree/bindings/usb/usb-phy.txt
 +++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
 @@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
   #phy-cells = 0;
   };

 -OMAP USB3 PHY
 +OMAP PIPE3 PHY

   Required properties:
 - - compatible: Should be ti,omap-usb3
 + - compatible: Should be ti,omap-usb3, ti,omap-pipe3, ti,omap-sata
 +   or ti,omap-pcie
- reg : Address and length of the register set for the device.
- reg-names: The names of the register addresses corresponding to the 
 registers
  filled in reg.
 diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
 index ac239ac..5c2e7a0 100644
 --- a/drivers/phy/Kconfig
 +++ b/drivers/phy/Kconfig
 @@ -27,6 +27,16 @@ config OMAP_USB2
 The USB OTG controller communicates with the comparator using this
 driver.

 +config OMAP_PIPE3
 +tristate OMAP PIPE3 PHY Driver
 +select GENERIC_PHY
 +select OMAP_CONTROL_USB
 how about
 depends on OMAP_CONTROL_USB

 From whatever I could make out from comments of Greg in my Generic PHY 
 Framework, it's better to do a select of dependent modules instead of 
 depends on.

 You can use select, provided the item you are selecting doesn't depend on 
 anything else.
 As OMAP_CONTROL_USB depends on ARCH_OMAP2PLUS, your configuration will fail 
 if a user enables
 OMAP_PIPE3 on non OMAP configuration.

 Further, in this case since it is OMAP related driver, there is no point in 
 showing/building it
 if OMAP platform is not selected, so you at least need [depends on 
 ARCH_OMAP2PLUS] to fix
 both issue I mentioned.


 Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.

 +help
 +  Enable this to support the PIPE3 PHY that is part of SOC. This

 worth mentioning TI OMAP/DRA SoCs.

 right.

 +  driver takes care of all the PHY functionality apart from 
 comparator.
 +  This driver interacts with the OMAP Control PHY Driver to power
 +  on/off the PHY.
 +
   config TWL4030_USB
   tristate TWL4030 USB Transceiver Driver
   depends on TWL4030_CORE  REGULATOR_TWL4030  USB_MUSB_OMAP2PLUS
 diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
 index 0dd8a98..48bf9f2 100644
 --- a/drivers/phy/Makefile
 +++ b/drivers/phy/Makefile
 @@ -4,4 +4,5 @@

   obj-$(CONFIG_GENERIC_PHY)+= phy-core.o
   obj-$(CONFIG_OMAP_USB2)+= phy-omap-usb2.o
 +obj-$(CONFIG_OMAP_PIPE3)+= phy-omap-pipe3.o
   obj-$(CONFIG_TWL4030_USB)+= phy-twl4030-usb.o
 diff --git a/drivers/usb/phy/phy-omap-usb3.c 
 b/drivers/phy/phy-omap-pipe3.c
 similarity index 57%
 rename from drivers/usb/phy/phy-omap-usb3.c
 rename to drivers/phy/phy-omap-pipe3.c
 index 4004f82..ee9a901 100644
 --- a/drivers/usb/phy/phy-omap-usb3.c
 +++ b/drivers/phy/phy-omap-pipe3.c
 @@ -1,5 +1,5 @@
   /*
 - * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
 + * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
*
* Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
* This program is free software; you can redistribute it and/or modify
 @@ -19,7 +19,8 @@
   #include linux/module.h
   #include linux/platform_device.h
   #include linux/slab.h
 -#include linux/usb/omap_usb.h
 +#include 

Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-10-14 Thread Roger Quadros
Kishon,

On 10/14/2013 12:19 PM, Kishon Vijay Abraham I wrote:
 Hi Roger,
 
 On Friday 11 October 2013 08:32 PM, Roger Quadros wrote:
 On 09/16/2013 10:37 AM, Roger Quadros wrote:
 On 09/16/2013 06:01 AM, Kishon Vijay Abraham I wrote:
 On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:
 Hi Kishon,

 On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:

   #ifdef CONFIG_OF
 -static const struct of_device_id omap_usb3_id_table[] = {
 +static const struct of_device_id omap_pipe3_id_table[] = {
 +{ .compatible = ti,omap-pipe3 },

 why do you need omap-pipe3, isn't sata, pcie and usb3 sufficient?

 I thought it would be better if everyone uses omap-pipe3 and added pcie, 
 sata if there are any specific settings (for pcie or sata) that should be 
 done.

 We can always add specialized options later when needed. AFAIK just the
 DPLL data is different among the different PHYs.

 +{ .compatible = ti,omap-sata },
 +{ .compatible = ti,omap-pcie },
   { .compatible = ti,omap-usb3 },

 I think compatible strings should be improved to indicate that it is a PHY.

 e.g. ti,omap-phy-sata or just ti,pipe3-phy-sata


 Please remove ti,omap-pcie for now, you can add it later whenever you add
 dpll settings for pcie.

 Also, please change the newly added compatible strings to

 ti,phy-pipe3-usb3 and ti,phy-pipe3-sata
 
 No, I think we should have omap in the compatible since this PHY is specific 
 to
 OMAP.

DRA7x and an am43x are not OMAP so I was suggesting not to use it for new PHY 
types.
We still preserve just ti,omap-usb3 for backward compatibility.

cheers,
-roger

--
To unsubscribe from this list: send the line unsubscribe linux-kernel in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/


Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-10-11 Thread Roger Quadros
On 09/16/2013 10:37 AM, Roger Quadros wrote:
> On 09/16/2013 06:01 AM, Kishon Vijay Abraham I wrote:
>> On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:
>>> Hi Kishon,
>>>
>>> On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:
 Adapted omap-usb3 PHY driver to Generic PHY Framework and moved 
 phy-omap-usb3
 driver in drivers/usb/phy to drivers/phy and also renamed the file to
 phy-omap-pipe3 since this same driver will be used for SATA PHY and
 PCIE PHY.
>>>
>>> I would suggest to split the renaming and PHY adaptation into 2 separate 
>>> patches.
>>
>> Alright.
>>>

 Signed-off-by: Kishon Vijay Abraham I 
 ---
   Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
   drivers/phy/Kconfig|   10 +
   drivers/phy/Makefile   |1 +
   .../phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c}   |  206 
 +++-
>>>
>>> how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as 
>>> non-OMAP e.g. DRA7.
>>
>> hmm.. I thought it would be consistent with other PHY drivers 
>> (phy-omap-usb2). Moreover DRA7 is OMAP based platform ;-) Maybe we should 
>> reserve that for later?
> 
> OK. Up to you.
> 
>>>
   drivers/usb/phy/Kconfig|   11 --
   drivers/usb/phy/Makefile   |1 -
   include/linux/phy/omap_pipe3.h |   52 +
   7 files changed, 177 insertions(+), 109 deletions(-)
   rename drivers/{usb/phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c} (57%)
   create mode 100644 include/linux/phy/omap_pipe3.h

 diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
 b/Documentation/devicetree/bindings/usb/usb-phy.txt
 index c0245c8..36bdb17 100644
 --- a/Documentation/devicetree/bindings/usb/usb-phy.txt
 +++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
 @@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
   #phy-cells = <0>;
   };

 -OMAP USB3 PHY
 +OMAP PIPE3 PHY

   Required properties:
 - - compatible: Should be "ti,omap-usb3"
 + - compatible: Should be "ti,omap-usb3", "ti,omap-pipe3", "ti,omap-sata"
 +   or "ti,omap-pcie"
- reg : Address and length of the register set for the device.
- reg-names: The names of the register addresses corresponding to the 
 registers
  filled in "reg".
 diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
 index ac239ac..5c2e7a0 100644
 --- a/drivers/phy/Kconfig
 +++ b/drivers/phy/Kconfig
 @@ -27,6 +27,16 @@ config OMAP_USB2
 The USB OTG controller communicates with the comparator using this
 driver.

 +config OMAP_PIPE3
 +tristate "OMAP PIPE3 PHY Driver"
 +select GENERIC_PHY
 +select OMAP_CONTROL_USB
>>> how about
>>> depends on OMAP_CONTROL_USB
>>
>> From whatever I could make out from comments of Greg in my Generic PHY 
>> Framework, it's better to do a select of dependent modules instead of 
>> depends on.
> 
> You can use select, provided the item you are selecting doesn't depend on 
> anything else.
> As OMAP_CONTROL_USB depends on ARCH_OMAP2PLUS, your configuration will fail 
> if a user enables
> OMAP_PIPE3 on non OMAP configuration.
> 
> Further, in this case since it is OMAP related driver, there is no point in 
> showing/building it
> if OMAP platform is not selected, so you at least need [depends on 
> "ARCH_OMAP2PLUS"] to fix
> both issue I mentioned.
> 
>>>
>>> Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.
>>>
 +help
 +  Enable this to support the PIPE3 PHY that is part of SOC. This
>>>
>>> worth mentioning TI OMAP/DRA SoCs.
>>
>> right.
>>>
 +  driver takes care of all the PHY functionality apart from 
 comparator.
 +  This driver interacts with the "OMAP Control PHY Driver" to power
 +  on/off the PHY.
 +
   config TWL4030_USB
   tristate "TWL4030 USB Transceiver Driver"
   depends on TWL4030_CORE && REGULATOR_TWL4030 && USB_MUSB_OMAP2PLUS
 diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
 index 0dd8a98..48bf9f2 100644
 --- a/drivers/phy/Makefile
 +++ b/drivers/phy/Makefile
 @@ -4,4 +4,5 @@

   obj-$(CONFIG_GENERIC_PHY)+= phy-core.o
   obj-$(CONFIG_OMAP_USB2)+= phy-omap-usb2.o
 +obj-$(CONFIG_OMAP_PIPE3)+= phy-omap-pipe3.o
   obj-$(CONFIG_TWL4030_USB)+= phy-twl4030-usb.o
 diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
 similarity index 57%
 rename from drivers/usb/phy/phy-omap-usb3.c
 rename to drivers/phy/phy-omap-pipe3.c
 index 4004f82..ee9a901 100644
 --- a/drivers/usb/phy/phy-omap-usb3.c
 +++ b/drivers/phy/phy-omap-pipe3.c
 @@ -1,5 +1,5 @@
   /*
 - * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
 + * 

Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-10-11 Thread Roger Quadros
On 09/16/2013 10:37 AM, Roger Quadros wrote:
 On 09/16/2013 06:01 AM, Kishon Vijay Abraham I wrote:
 On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:
 Hi Kishon,

 On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:
 Adapted omap-usb3 PHY driver to Generic PHY Framework and moved 
 phy-omap-usb3
 driver in drivers/usb/phy to drivers/phy and also renamed the file to
 phy-omap-pipe3 since this same driver will be used for SATA PHY and
 PCIE PHY.

 I would suggest to split the renaming and PHY adaptation into 2 separate 
 patches.

 Alright.


 Signed-off-by: Kishon Vijay Abraham I kis...@ti.com
 ---
   Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
   drivers/phy/Kconfig|   10 +
   drivers/phy/Makefile   |1 +
   .../phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c}   |  206 
 +++-

 how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as 
 non-OMAP e.g. DRA7.

 hmm.. I thought it would be consistent with other PHY drivers 
 (phy-omap-usb2). Moreover DRA7 is OMAP based platform ;-) Maybe we should 
 reserve that for later?
 
 OK. Up to you.
 

   drivers/usb/phy/Kconfig|   11 --
   drivers/usb/phy/Makefile   |1 -
   include/linux/phy/omap_pipe3.h |   52 +
   7 files changed, 177 insertions(+), 109 deletions(-)
   rename drivers/{usb/phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c} (57%)
   create mode 100644 include/linux/phy/omap_pipe3.h

 diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
 b/Documentation/devicetree/bindings/usb/usb-phy.txt
 index c0245c8..36bdb17 100644
 --- a/Documentation/devicetree/bindings/usb/usb-phy.txt
 +++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
 @@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
   #phy-cells = 0;
   };

 -OMAP USB3 PHY
 +OMAP PIPE3 PHY

   Required properties:
 - - compatible: Should be ti,omap-usb3
 + - compatible: Should be ti,omap-usb3, ti,omap-pipe3, ti,omap-sata
 +   or ti,omap-pcie
- reg : Address and length of the register set for the device.
- reg-names: The names of the register addresses corresponding to the 
 registers
  filled in reg.
 diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
 index ac239ac..5c2e7a0 100644
 --- a/drivers/phy/Kconfig
 +++ b/drivers/phy/Kconfig
 @@ -27,6 +27,16 @@ config OMAP_USB2
 The USB OTG controller communicates with the comparator using this
 driver.

 +config OMAP_PIPE3
 +tristate OMAP PIPE3 PHY Driver
 +select GENERIC_PHY
 +select OMAP_CONTROL_USB
 how about
 depends on OMAP_CONTROL_USB

 From whatever I could make out from comments of Greg in my Generic PHY 
 Framework, it's better to do a select of dependent modules instead of 
 depends on.
 
 You can use select, provided the item you are selecting doesn't depend on 
 anything else.
 As OMAP_CONTROL_USB depends on ARCH_OMAP2PLUS, your configuration will fail 
 if a user enables
 OMAP_PIPE3 on non OMAP configuration.
 
 Further, in this case since it is OMAP related driver, there is no point in 
 showing/building it
 if OMAP platform is not selected, so you at least need [depends on 
 ARCH_OMAP2PLUS] to fix
 both issue I mentioned.
 

 Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.

 +help
 +  Enable this to support the PIPE3 PHY that is part of SOC. This

 worth mentioning TI OMAP/DRA SoCs.

 right.

 +  driver takes care of all the PHY functionality apart from 
 comparator.
 +  This driver interacts with the OMAP Control PHY Driver to power
 +  on/off the PHY.
 +
   config TWL4030_USB
   tristate TWL4030 USB Transceiver Driver
   depends on TWL4030_CORE  REGULATOR_TWL4030  USB_MUSB_OMAP2PLUS
 diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
 index 0dd8a98..48bf9f2 100644
 --- a/drivers/phy/Makefile
 +++ b/drivers/phy/Makefile
 @@ -4,4 +4,5 @@

   obj-$(CONFIG_GENERIC_PHY)+= phy-core.o
   obj-$(CONFIG_OMAP_USB2)+= phy-omap-usb2.o
 +obj-$(CONFIG_OMAP_PIPE3)+= phy-omap-pipe3.o
   obj-$(CONFIG_TWL4030_USB)+= phy-twl4030-usb.o
 diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
 similarity index 57%
 rename from drivers/usb/phy/phy-omap-usb3.c
 rename to drivers/phy/phy-omap-pipe3.c
 index 4004f82..ee9a901 100644
 --- a/drivers/usb/phy/phy-omap-usb3.c
 +++ b/drivers/phy/phy-omap-pipe3.c
 @@ -1,5 +1,5 @@
   /*
 - * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
 + * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
*
* Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
* This program is free software; you can redistribute it and/or modify
 @@ -19,7 +19,8 @@
   #include linux/module.h
   #include linux/platform_device.h
   #include linux/slab.h
 -#include linux/usb/omap_usb.h
 +#include linux/phy/omap_pipe3.h
 +#include linux/phy/phy.h
   #include linux/of.h
   #include 

Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-09-16 Thread Roger Quadros
On 09/16/2013 06:01 AM, Kishon Vijay Abraham I wrote:
> On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:
>> Hi Kishon,
>>
>> On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:
>>> Adapted omap-usb3 PHY driver to Generic PHY Framework and moved 
>>> phy-omap-usb3
>>> driver in drivers/usb/phy to drivers/phy and also renamed the file to
>>> phy-omap-pipe3 since this same driver will be used for SATA PHY and
>>> PCIE PHY.
>>
>> I would suggest to split the renaming and PHY adaptation into 2 separate 
>> patches.
> 
> Alright.
>>
>>>
>>> Signed-off-by: Kishon Vijay Abraham I 
>>> ---
>>>   Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
>>>   drivers/phy/Kconfig|   10 +
>>>   drivers/phy/Makefile   |1 +
>>>   .../phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c}   |  206 
>>> +++-
>>
>> how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as 
>> non-OMAP e.g. DRA7.
> 
> hmm.. I thought it would be consistent with other PHY drivers 
> (phy-omap-usb2). Moreover DRA7 is OMAP based platform ;-) Maybe we should 
> reserve that for later?

OK. Up to you.

>>
>>>   drivers/usb/phy/Kconfig|   11 --
>>>   drivers/usb/phy/Makefile   |1 -
>>>   include/linux/phy/omap_pipe3.h |   52 +
>>>   7 files changed, 177 insertions(+), 109 deletions(-)
>>>   rename drivers/{usb/phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c} (57%)
>>>   create mode 100644 include/linux/phy/omap_pipe3.h
>>>
>>> diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
>>> b/Documentation/devicetree/bindings/usb/usb-phy.txt
>>> index c0245c8..36bdb17 100644
>>> --- a/Documentation/devicetree/bindings/usb/usb-phy.txt
>>> +++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
>>> @@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
>>>   #phy-cells = <0>;
>>>   };
>>>
>>> -OMAP USB3 PHY
>>> +OMAP PIPE3 PHY
>>>
>>>   Required properties:
>>> - - compatible: Should be "ti,omap-usb3"
>>> + - compatible: Should be "ti,omap-usb3", "ti,omap-pipe3", "ti,omap-sata"
>>> +   or "ti,omap-pcie"
>>>- reg : Address and length of the register set for the device.
>>>- reg-names: The names of the register addresses corresponding to the 
>>> registers
>>>  filled in "reg".
>>> diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
>>> index ac239ac..5c2e7a0 100644
>>> --- a/drivers/phy/Kconfig
>>> +++ b/drivers/phy/Kconfig
>>> @@ -27,6 +27,16 @@ config OMAP_USB2
>>> The USB OTG controller communicates with the comparator using this
>>> driver.
>>>
>>> +config OMAP_PIPE3
>>> +tristate "OMAP PIPE3 PHY Driver"
>>> +select GENERIC_PHY
>>> +select OMAP_CONTROL_USB
>> how about
>> depends on OMAP_CONTROL_USB
> 
> From whatever I could make out from comments of Greg in my Generic PHY 
> Framework, it's better to do a select of dependent modules instead of depends 
> on.

You can use select, provided the item you are selecting doesn't depend on 
anything else.
As OMAP_CONTROL_USB depends on ARCH_OMAP2PLUS, your configuration will fail if 
a user enables
OMAP_PIPE3 on non OMAP configuration.

Further, in this case since it is OMAP related driver, there is no point in 
showing/building it
if OMAP platform is not selected, so you at least need [depends on 
"ARCH_OMAP2PLUS"] to fix
both issue I mentioned.

>>
>> Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.
>>
>>> +help
>>> +  Enable this to support the PIPE3 PHY that is part of SOC. This
>>
>> worth mentioning TI OMAP/DRA SoCs.
> 
> right.
>>
>>> +  driver takes care of all the PHY functionality apart from comparator.
>>> +  This driver interacts with the "OMAP Control PHY Driver" to power
>>> +  on/off the PHY.
>>> +
>>>   config TWL4030_USB
>>>   tristate "TWL4030 USB Transceiver Driver"
>>>   depends on TWL4030_CORE && REGULATOR_TWL4030 && USB_MUSB_OMAP2PLUS
>>> diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
>>> index 0dd8a98..48bf9f2 100644
>>> --- a/drivers/phy/Makefile
>>> +++ b/drivers/phy/Makefile
>>> @@ -4,4 +4,5 @@
>>>
>>>   obj-$(CONFIG_GENERIC_PHY)+= phy-core.o
>>>   obj-$(CONFIG_OMAP_USB2)+= phy-omap-usb2.o
>>> +obj-$(CONFIG_OMAP_PIPE3)+= phy-omap-pipe3.o
>>>   obj-$(CONFIG_TWL4030_USB)+= phy-twl4030-usb.o
>>> diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
>>> similarity index 57%
>>> rename from drivers/usb/phy/phy-omap-usb3.c
>>> rename to drivers/phy/phy-omap-pipe3.c
>>> index 4004f82..ee9a901 100644
>>> --- a/drivers/usb/phy/phy-omap-usb3.c
>>> +++ b/drivers/phy/phy-omap-pipe3.c
>>> @@ -1,5 +1,5 @@
>>>   /*
>>> - * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
>>> + * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
>>>*
>>>* Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
>>>* This program is free software; you can 

Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-09-16 Thread Roger Quadros
On 09/16/2013 06:01 AM, Kishon Vijay Abraham I wrote:
 On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:
 Hi Kishon,

 On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:
 Adapted omap-usb3 PHY driver to Generic PHY Framework and moved 
 phy-omap-usb3
 driver in drivers/usb/phy to drivers/phy and also renamed the file to
 phy-omap-pipe3 since this same driver will be used for SATA PHY and
 PCIE PHY.

 I would suggest to split the renaming and PHY adaptation into 2 separate 
 patches.
 
 Alright.


 Signed-off-by: Kishon Vijay Abraham I kis...@ti.com
 ---
   Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
   drivers/phy/Kconfig|   10 +
   drivers/phy/Makefile   |1 +
   .../phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c}   |  206 
 +++-

 how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as 
 non-OMAP e.g. DRA7.
 
 hmm.. I thought it would be consistent with other PHY drivers 
 (phy-omap-usb2). Moreover DRA7 is OMAP based platform ;-) Maybe we should 
 reserve that for later?

OK. Up to you.


   drivers/usb/phy/Kconfig|   11 --
   drivers/usb/phy/Makefile   |1 -
   include/linux/phy/omap_pipe3.h |   52 +
   7 files changed, 177 insertions(+), 109 deletions(-)
   rename drivers/{usb/phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c} (57%)
   create mode 100644 include/linux/phy/omap_pipe3.h

 diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
 b/Documentation/devicetree/bindings/usb/usb-phy.txt
 index c0245c8..36bdb17 100644
 --- a/Documentation/devicetree/bindings/usb/usb-phy.txt
 +++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
 @@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
   #phy-cells = 0;
   };

 -OMAP USB3 PHY
 +OMAP PIPE3 PHY

   Required properties:
 - - compatible: Should be ti,omap-usb3
 + - compatible: Should be ti,omap-usb3, ti,omap-pipe3, ti,omap-sata
 +   or ti,omap-pcie
- reg : Address and length of the register set for the device.
- reg-names: The names of the register addresses corresponding to the 
 registers
  filled in reg.
 diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
 index ac239ac..5c2e7a0 100644
 --- a/drivers/phy/Kconfig
 +++ b/drivers/phy/Kconfig
 @@ -27,6 +27,16 @@ config OMAP_USB2
 The USB OTG controller communicates with the comparator using this
 driver.

 +config OMAP_PIPE3
 +tristate OMAP PIPE3 PHY Driver
 +select GENERIC_PHY
 +select OMAP_CONTROL_USB
 how about
 depends on OMAP_CONTROL_USB
 
 From whatever I could make out from comments of Greg in my Generic PHY 
 Framework, it's better to do a select of dependent modules instead of depends 
 on.

You can use select, provided the item you are selecting doesn't depend on 
anything else.
As OMAP_CONTROL_USB depends on ARCH_OMAP2PLUS, your configuration will fail if 
a user enables
OMAP_PIPE3 on non OMAP configuration.

Further, in this case since it is OMAP related driver, there is no point in 
showing/building it
if OMAP platform is not selected, so you at least need [depends on 
ARCH_OMAP2PLUS] to fix
both issue I mentioned.


 Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.

 +help
 +  Enable this to support the PIPE3 PHY that is part of SOC. This

 worth mentioning TI OMAP/DRA SoCs.
 
 right.

 +  driver takes care of all the PHY functionality apart from comparator.
 +  This driver interacts with the OMAP Control PHY Driver to power
 +  on/off the PHY.
 +
   config TWL4030_USB
   tristate TWL4030 USB Transceiver Driver
   depends on TWL4030_CORE  REGULATOR_TWL4030  USB_MUSB_OMAP2PLUS
 diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
 index 0dd8a98..48bf9f2 100644
 --- a/drivers/phy/Makefile
 +++ b/drivers/phy/Makefile
 @@ -4,4 +4,5 @@

   obj-$(CONFIG_GENERIC_PHY)+= phy-core.o
   obj-$(CONFIG_OMAP_USB2)+= phy-omap-usb2.o
 +obj-$(CONFIG_OMAP_PIPE3)+= phy-omap-pipe3.o
   obj-$(CONFIG_TWL4030_USB)+= phy-twl4030-usb.o
 diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
 similarity index 57%
 rename from drivers/usb/phy/phy-omap-usb3.c
 rename to drivers/phy/phy-omap-pipe3.c
 index 4004f82..ee9a901 100644
 --- a/drivers/usb/phy/phy-omap-usb3.c
 +++ b/drivers/phy/phy-omap-pipe3.c
 @@ -1,5 +1,5 @@
   /*
 - * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
 + * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
*
* Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
* This program is free software; you can redistribute it and/or modify
 @@ -19,7 +19,8 @@
   #include linux/module.h
   #include linux/platform_device.h
   #include linux/slab.h
 -#include linux/usb/omap_usb.h
 +#include linux/phy/omap_pipe3.h
 +#include linux/phy/phy.h
   #include linux/of.h
   #include linux/clk.h
   #include linux/err.h
 @@ -52,17 +53,17 @@

  

Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-09-15 Thread Kishon Vijay Abraham I

On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:

Hi Kishon,

On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:

Adapted omap-usb3 PHY driver to Generic PHY Framework and moved phy-omap-usb3
driver in drivers/usb/phy to drivers/phy and also renamed the file to
phy-omap-pipe3 since this same driver will be used for SATA PHY and
PCIE PHY.


I would suggest to split the renaming and PHY adaptation into 2 separate 
patches.


Alright.




Signed-off-by: Kishon Vijay Abraham I 
---
  Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
  drivers/phy/Kconfig|   10 +
  drivers/phy/Makefile   |1 +
  .../phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c}   |  206 +++-


how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as non-OMAP 
e.g. DRA7.


hmm.. I thought it would be consistent with other PHY drivers 
(phy-omap-usb2). Moreover DRA7 is OMAP based platform ;-) Maybe we 
should reserve that for later?



  drivers/usb/phy/Kconfig|   11 --
  drivers/usb/phy/Makefile   |1 -
  include/linux/phy/omap_pipe3.h |   52 +
  7 files changed, 177 insertions(+), 109 deletions(-)
  rename drivers/{usb/phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c} (57%)
  create mode 100644 include/linux/phy/omap_pipe3.h

diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
b/Documentation/devicetree/bindings/usb/usb-phy.txt
index c0245c8..36bdb17 100644
--- a/Documentation/devicetree/bindings/usb/usb-phy.txt
+++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
@@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
#phy-cells = <0>;
  };

-OMAP USB3 PHY
+OMAP PIPE3 PHY

  Required properties:
- - compatible: Should be "ti,omap-usb3"
+ - compatible: Should be "ti,omap-usb3", "ti,omap-pipe3", "ti,omap-sata"
+   or "ti,omap-pcie"
   - reg : Address and length of the register set for the device.
   - reg-names: The names of the register addresses corresponding to the 
registers
 filled in "reg".
diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
index ac239ac..5c2e7a0 100644
--- a/drivers/phy/Kconfig
+++ b/drivers/phy/Kconfig
@@ -27,6 +27,16 @@ config OMAP_USB2
  The USB OTG controller communicates with the comparator using this
  driver.

+config OMAP_PIPE3
+   tristate "OMAP PIPE3 PHY Driver"
+   select GENERIC_PHY
+   select OMAP_CONTROL_USB

how about
depends on OMAP_CONTROL_USB


From whatever I could make out from comments of Greg in my Generic PHY 
Framework, it's better to do a select of dependent modules instead of 
depends on.


Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.


+   help
+ Enable this to support the PIPE3 PHY that is part of SOC. This


worth mentioning TI OMAP/DRA SoCs.


right.



+ driver takes care of all the PHY functionality apart from comparator.
+ This driver interacts with the "OMAP Control PHY Driver" to power
+ on/off the PHY.
+
  config TWL4030_USB
tristate "TWL4030 USB Transceiver Driver"
depends on TWL4030_CORE && REGULATOR_TWL4030 && USB_MUSB_OMAP2PLUS
diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
index 0dd8a98..48bf9f2 100644
--- a/drivers/phy/Makefile
+++ b/drivers/phy/Makefile
@@ -4,4 +4,5 @@

  obj-$(CONFIG_GENERIC_PHY) += phy-core.o
  obj-$(CONFIG_OMAP_USB2)   += phy-omap-usb2.o
+obj-$(CONFIG_OMAP_PIPE3)   += phy-omap-pipe3.o
  obj-$(CONFIG_TWL4030_USB) += phy-twl4030-usb.o
diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
b/Documentation/devicetree/bindings/usb/usb-phy.txt
index c0245c8..36bdb17 100644
--- a/Documentation/devicetree/bindings/usb/usb-phy.txt
+++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
@@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
#phy-cells = 0;
  };

-OMAP USB3 PHY
+OMAP PIPE3 PHY

  Required properties:
- - compatible: Should be ti,omap-usb3
+ - compatible: Should be ti,omap-usb3, ti,omap-pipe3, ti,omap-sata
+   or ti,omap-pcie
   - reg : Address and length of the register set for the device.
   - reg-names: The names of the register addresses corresponding to the 
registers
 filled in reg.
diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
index ac239ac..5c2e7a0 100644
--- a/drivers/phy/Kconfig
+++ b/drivers/phy/Kconfig
@@ -27,6 +27,16 @@ config OMAP_USB2
  The USB OTG controller communicates with the comparator using this
  driver.

+config OMAP_PIPE3
+   tristate OMAP PIPE3 PHY Driver
+   select GENERIC_PHY
+   select OMAP_CONTROL_USB

how about
depends on OMAP_CONTROL_USB


From whatever I could make out from comments of Greg in my Generic PHY 
Framework, it's better to do a select of dependent modules instead of 
depends on.


Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.


+   help
+ Enable this to support the PIPE3 PHY that is part of SOC. This


worth mentioning TI OMAP/DRA SoCs.


right.



+ driver takes care of all the PHY functionality apart from comparator.
+ This driver interacts with the OMAP Control PHY Driver to power
+ on/off the PHY.
+
  config TWL4030_USB
tristate TWL4030 USB Transceiver Driver
depends on TWL4030_CORE  REGULATOR_TWL4030  USB_MUSB_OMAP2PLUS
diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
index 0dd8a98..48bf9f2 100644
--- a/drivers/phy/Makefile
+++ b/drivers/phy/Makefile
@@ -4,4 +4,5 @@

  obj-$(CONFIG_GENERIC_PHY) += phy-core.o
  obj-$(CONFIG_OMAP_USB2)   += phy-omap-usb2.o
+obj-$(CONFIG_OMAP_PIPE3)   += phy-omap-pipe3.o
  obj-$(CONFIG_TWL4030_USB) += phy-twl4030-usb.o
diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
b/Documentation/devicetree/bindings/usb/usb-phy.txt
index c0245c8..36bdb17 100644
--- a/Documentation/devicetree/bindings/usb/usb-phy.txt
+++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
@@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
#phy-cells = <0>;
 };
 
-OMAP USB3 PHY
+OMAP PIPE3 PHY
 
 Required properties:
- - compatible: Should be "ti,omap-usb3"
+ - compatible: Should be "ti,omap-usb3", "ti,omap-pipe3", "ti,omap-sata"
+   or "ti,omap-pcie"
  - reg : Address and length of the register set for the device.
  - reg-names: The names of the register addresses corresponding to the 
registers
filled in "reg".
diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
index ac239ac..5c2e7a0 100644
--- a/drivers/phy/Kconfig
+++ b/drivers/phy/Kconfig
@@ -27,6 +27,16 @@ config OMAP_USB2
  The USB OTG controller communicates with the comparator using this
  driver.
 
+config OMAP_PIPE3
+   tristate "OMAP PIPE3 PHY Driver"
+   select GENERIC_PHY
+   select OMAP_CONTROL_USB
+   help
+ Enable this to support the PIPE3 PHY that is part of SOC. This
+ driver takes care of all the PHY functionality apart from comparator.
+ This driver interacts with the "OMAP Control PHY Driver" to power
+ on/off the PHY.
+
 config TWL4030_USB
tristate "TWL4030 USB Transceiver Driver"
depends on TWL4030_CORE && REGULATOR_TWL4030 && USB_MUSB_OMAP2PLUS
diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
index 0dd8a98..48bf9f2 100644
--- a/drivers/phy/Makefile
+++ b/drivers/phy/Makefile
@@ -4,4 +4,5 @@
 
 obj-$(CONFIG_GENERIC_PHY)  += phy-core.o
 obj-$(CONFIG_OMAP_USB2)+= phy-omap-usb2.o
+obj-$(CONFIG_OMAP_PIPE3)   += phy-omap-pipe3.o
 obj-$(CONFIG_TWL4030_USB)  += phy-twl4030-usb.o
diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
b/Documentation/devicetree/bindings/usb/usb-phy.txt
index c0245c8..36bdb17 100644
--- a/Documentation/devicetree/bindings/usb/usb-phy.txt
+++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
@@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
#phy-cells = 0;
 };
 
-OMAP USB3 PHY
+OMAP PIPE3 PHY
 
 Required properties:
- - compatible: Should be ti,omap-usb3
+ - compatible: Should be ti,omap-usb3, ti,omap-pipe3, ti,omap-sata
+   or ti,omap-pcie
  - reg : Address and length of the register set for the device.
  - reg-names: The names of the register addresses corresponding to the 
registers
filled in reg.
diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
index ac239ac..5c2e7a0 100644
--- a/drivers/phy/Kconfig
+++ b/drivers/phy/Kconfig
@@ -27,6 +27,16 @@ config OMAP_USB2
  The USB OTG controller communicates with the comparator using this
  driver.
 
+config OMAP_PIPE3
+   tristate OMAP PIPE3 PHY Driver
+   select GENERIC_PHY
+   select OMAP_CONTROL_USB
+   help
+ Enable this to support the PIPE3 PHY that is part of SOC. This
+ driver takes care of all the PHY functionality apart from comparator.
+ This driver interacts with the OMAP Control PHY Driver to power
+ on/off the PHY.
+
 config TWL4030_USB
tristate TWL4030 USB Transceiver Driver
depends on TWL4030_CORE  REGULATOR_TWL4030  USB_MUSB_OMAP2PLUS
diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
index 0dd8a98..48bf9f2 100644
--- a/drivers/phy/Makefile
+++ b/drivers/phy/Makefile
@@ -4,4 +4,5 @@
 
 obj-$(CONFIG_GENERIC_PHY)  += phy-core.o
 obj-$(CONFIG_OMAP_USB2)+= phy-omap-usb2.o
+obj-$(CONFIG_OMAP_PIPE3)   += phy-omap-pipe3.o
 obj-$(CONFIG_TWL4030_USB)  += phy-twl4030-usb.o
diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
similarity index 57%
rename from drivers/usb/phy/phy-omap-usb3.c
rename to drivers/phy/phy-omap-pipe3.c
index 4004f82..ee9a901 100644
--- a/drivers/usb/phy/phy-omap-usb3.c
+++ b/drivers/phy/phy-omap-pipe3.c
@@ -1,5 +1,5 @@
  /*
- * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
+ * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
   *
   * Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
   * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,8 @@
  #include 
  #include 
  #include 
-#include 
+#include 
+#include 
  #include 
  #include 
  #include 
@@ -52,17 +53,17 @@

  /*
   * This is an Empirical value that works, need to confirm the actual
  * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
  * to be correctly reflected in the USB3PHY_PLL_STATUS register.
   */
  # define PLL_IDLE_TIME  100;

-struct usb_dpll_map {
+struct pipe3_dpll_map {
unsigned long rate;
-   struct usb_dpll_params params;
+   struct pipe3_dpll_params params;
  };

-static struct usb_dpll_map dpll_map[] = {
+static struct pipe3_dpll_map dpll_map[] = {
{1200, {1250, 5, 4, 20, 0} },   

Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-09-15 Thread Kishon Vijay Abraham I

On Thursday 12 September 2013 04:49 PM, Roger Quadros wrote:

Hi Kishon,

On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:

Adapted omap-usb3 PHY driver to Generic PHY Framework and moved phy-omap-usb3
driver in drivers/usb/phy to drivers/phy and also renamed the file to
phy-omap-pipe3 since this same driver will be used for SATA PHY and
PCIE PHY.


I would suggest to split the renaming and PHY adaptation into 2 separate 
patches.


Alright.




Signed-off-by: Kishon Vijay Abraham I kis...@ti.com
---
  Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
  drivers/phy/Kconfig|   10 +
  drivers/phy/Makefile   |1 +
@@ -52,17 +53,17 @@
  /*
   * This is an Empirical value that works, need to confirm the actual
- * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
- * to be correctly reflected in the USB3PHY_PLL_STATUS register.
+ * value required for the PIPE3PHY_PLL_CONFIGURATION2.PLL_IDLE status
+ * to be correctly reflected in the PIPE3PHY_PLL_STATUS register.
   */
  # define PLL_IDLE_TIME  100;
  .../phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c}   |  206 +++-


how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as non-OMAP 
e.g. DRA7.


hmm.. I thought it would be consistent with other PHY drivers 
(phy-omap-usb2). Moreover DRA7 is OMAP based platform ;-) Maybe we 
should reserve that for later?



  drivers/usb/phy/Kconfig|   11 --
  drivers/usb/phy/Makefile   |1 -
  include/linux/phy/omap_pipe3.h |   52 +
  7 files changed, 177 insertions(+), 109 deletions(-)
  rename drivers/{usb/phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c} (57%)
  create mode 100644 include/linux/phy/omap_pipe3.h

diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
similarity index 57%
rename from drivers/usb/phy/phy-omap-usb3.c
rename to drivers/phy/phy-omap-pipe3.c
index 4004f82..ee9a901 100644
--- a/drivers/usb/phy/phy-omap-usb3.c
+++ b/drivers/phy/phy-omap-pipe3.c
@@ -1,5 +1,5 @@
  /*
- * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
+ * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
   *
   * Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
   * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,8 @@
  #include linux/module.h
  #include linux/platform_device.h
  #include linux/slab.h
-#include linux/usb/omap_usb.h
+#include linux/phy/omap_pipe3.h
+#include linux/phy/phy.h
  #include linux/of.h
  #include linux/clk.h
  #include linux/err.h
@@ -52,17 +53,17 @@

  /*
   * This is an Empirical value that works, need to confirm the actual
  * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
  * to be correctly reflected in the USB3PHY_PLL_STATUS register.
   */
  # define PLL_IDLE_TIME  100;

-struct usb_dpll_map {
+struct pipe3_dpll_map {
unsigned long rate;
-   struct usb_dpll_params params;
+   struct pipe3_dpll_params params;
  };


Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-09-12 Thread Roger Quadros
Hi Kishon,

On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:
> Adapted omap-usb3 PHY driver to Generic PHY Framework and moved phy-omap-usb3
> driver in drivers/usb/phy to drivers/phy and also renamed the file to
> phy-omap-pipe3 since this same driver will be used for SATA PHY and
> PCIE PHY.

I would suggest to split the renaming and PHY adaptation into 2 separate 
patches.

> 
> Signed-off-by: Kishon Vijay Abraham I 
> ---
>  Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
>  drivers/phy/Kconfig|   10 +
>  drivers/phy/Makefile   |1 +
>  .../phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c}   |  206 
> +++-

how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as non-OMAP 
e.g. DRA7.

>  drivers/usb/phy/Kconfig|   11 --
>  drivers/usb/phy/Makefile   |1 -
>  include/linux/phy/omap_pipe3.h |   52 +
>  7 files changed, 177 insertions(+), 109 deletions(-)
>  rename drivers/{usb/phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c} (57%)
>  create mode 100644 include/linux/phy/omap_pipe3.h
> 
> diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
> b/Documentation/devicetree/bindings/usb/usb-phy.txt
> index c0245c8..36bdb17 100644
> --- a/Documentation/devicetree/bindings/usb/usb-phy.txt
> +++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
> @@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
>   #phy-cells = <0>;
>  };
>  
> -OMAP USB3 PHY
> +OMAP PIPE3 PHY
>  
>  Required properties:
> - - compatible: Should be "ti,omap-usb3"
> + - compatible: Should be "ti,omap-usb3", "ti,omap-pipe3", "ti,omap-sata"
> +   or "ti,omap-pcie"
>   - reg : Address and length of the register set for the device.
>   - reg-names: The names of the register addresses corresponding to the 
> registers
> filled in "reg".
> diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
> index ac239ac..5c2e7a0 100644
> --- a/drivers/phy/Kconfig
> +++ b/drivers/phy/Kconfig
> @@ -27,6 +27,16 @@ config OMAP_USB2
> The USB OTG controller communicates with the comparator using this
> driver.
>  
> +config OMAP_PIPE3
> + tristate "OMAP PIPE3 PHY Driver"
> + select GENERIC_PHY
> + select OMAP_CONTROL_USB
how about
depends on OMAP_CONTROL_USB

Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.

> + help
> +   Enable this to support the PIPE3 PHY that is part of SOC. This

worth mentioning TI OMAP/DRA SoCs.

> +   driver takes care of all the PHY functionality apart from comparator.
> +   This driver interacts with the "OMAP Control PHY Driver" to power
> +   on/off the PHY.
> +
>  config TWL4030_USB
>   tristate "TWL4030 USB Transceiver Driver"
>   depends on TWL4030_CORE && REGULATOR_TWL4030 && USB_MUSB_OMAP2PLUS
> diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
> index 0dd8a98..48bf9f2 100644
> --- a/drivers/phy/Makefile
> +++ b/drivers/phy/Makefile
> @@ -4,4 +4,5 @@
>  
>  obj-$(CONFIG_GENERIC_PHY)+= phy-core.o
>  obj-$(CONFIG_OMAP_USB2)  += phy-omap-usb2.o
> +obj-$(CONFIG_OMAP_PIPE3) += phy-omap-pipe3.o
>  obj-$(CONFIG_TWL4030_USB)+= phy-twl4030-usb.o
> diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
> similarity index 57%
> rename from drivers/usb/phy/phy-omap-usb3.c
> rename to drivers/phy/phy-omap-pipe3.c
> index 4004f82..ee9a901 100644
> --- a/drivers/usb/phy/phy-omap-usb3.c
> +++ b/drivers/phy/phy-omap-pipe3.c
> @@ -1,5 +1,5 @@
>  /*
> - * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
> + * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
>   *
>   * Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
>   * This program is free software; you can redistribute it and/or modify
> @@ -19,7 +19,8 @@
>  #include 
>  #include 
>  #include 
> -#include 
> +#include 
> +#include 
>  #include 
>  #include 
>  #include 
> @@ -52,17 +53,17 @@
>  
>  /*
>   * This is an Empirical value that works, need to confirm the actual
> - * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
> - * to be correctly reflected in the USB3PHY_PLL_STATUS register.
> + * value required for the PIPE3PHY_PLL_CONFIGURATION2.PLL_IDLE status
> + * to be correctly reflected in the PIPE3PHY_PLL_STATUS register.
>   */
>  # define PLL_IDLE_TIME  100;
>  
> -struct usb_dpll_map {
> +struct pipe3_dpll_map {
>   unsigned long rate;
> - struct usb_dpll_params params;
> + struct pipe3_dpll_params params;
>  };
>  
> -static struct usb_dpll_map dpll_map[] = {
> +static struct pipe3_dpll_map dpll_map[] = {
>   {1200, {1250, 5, 4, 20, 0} },   /* 12 MHz */
>   {1680, {3125, 20, 4, 20, 0} },  /* 16.8 MHz */
>   {1920, {1172, 8, 4, 20, 65537} },   /* 19.2 MHz */
> @@ -71,7 +72,7 @@ static struct usb_dpll_map dpll_map[] = {
>   {3840, {3125, 47, 4, 20, 92843} }, 

Re: [PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-09-12 Thread Roger Quadros
Hi Kishon,

On 09/02/2013 06:43 PM, Kishon Vijay Abraham I wrote:
 Adapted omap-usb3 PHY driver to Generic PHY Framework and moved phy-omap-usb3
 driver in drivers/usb/phy to drivers/phy and also renamed the file to
 phy-omap-pipe3 since this same driver will be used for SATA PHY and
 PCIE PHY.

I would suggest to split the renaming and PHY adaptation into 2 separate 
patches.

 
 Signed-off-by: Kishon Vijay Abraham I kis...@ti.com
 ---
  Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
  drivers/phy/Kconfig|   10 +
  drivers/phy/Makefile   |1 +
  .../phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c}   |  206 
 +++-

how about naming it to phy-ti-pipe3.c as it is used on OMAP as well as non-OMAP 
e.g. DRA7.

  drivers/usb/phy/Kconfig|   11 --
  drivers/usb/phy/Makefile   |1 -
  include/linux/phy/omap_pipe3.h |   52 +
  7 files changed, 177 insertions(+), 109 deletions(-)
  rename drivers/{usb/phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c} (57%)
  create mode 100644 include/linux/phy/omap_pipe3.h
 
 diff --git a/Documentation/devicetree/bindings/usb/usb-phy.txt 
 b/Documentation/devicetree/bindings/usb/usb-phy.txt
 index c0245c8..36bdb17 100644
 --- a/Documentation/devicetree/bindings/usb/usb-phy.txt
 +++ b/Documentation/devicetree/bindings/usb/usb-phy.txt
 @@ -21,10 +21,11 @@ usb2phy@4a0ad080 {
   #phy-cells = 0;
  };
  
 -OMAP USB3 PHY
 +OMAP PIPE3 PHY
  
  Required properties:
 - - compatible: Should be ti,omap-usb3
 + - compatible: Should be ti,omap-usb3, ti,omap-pipe3, ti,omap-sata
 +   or ti,omap-pcie
   - reg : Address and length of the register set for the device.
   - reg-names: The names of the register addresses corresponding to the 
 registers
 filled in reg.
 diff --git a/drivers/phy/Kconfig b/drivers/phy/Kconfig
 index ac239ac..5c2e7a0 100644
 --- a/drivers/phy/Kconfig
 +++ b/drivers/phy/Kconfig
 @@ -27,6 +27,16 @@ config OMAP_USB2
 The USB OTG controller communicates with the comparator using this
 driver.
  
 +config OMAP_PIPE3
 + tristate OMAP PIPE3 PHY Driver
 + select GENERIC_PHY
 + select OMAP_CONTROL_USB
how about
depends on OMAP_CONTROL_USB

Also, if this is TI/OMAP it might as well depend on ARCH_OMAP.

 + help
 +   Enable this to support the PIPE3 PHY that is part of SOC. This

worth mentioning TI OMAP/DRA SoCs.

 +   driver takes care of all the PHY functionality apart from comparator.
 +   This driver interacts with the OMAP Control PHY Driver to power
 +   on/off the PHY.
 +
  config TWL4030_USB
   tristate TWL4030 USB Transceiver Driver
   depends on TWL4030_CORE  REGULATOR_TWL4030  USB_MUSB_OMAP2PLUS
 diff --git a/drivers/phy/Makefile b/drivers/phy/Makefile
 index 0dd8a98..48bf9f2 100644
 --- a/drivers/phy/Makefile
 +++ b/drivers/phy/Makefile
 @@ -4,4 +4,5 @@
  
  obj-$(CONFIG_GENERIC_PHY)+= phy-core.o
  obj-$(CONFIG_OMAP_USB2)  += phy-omap-usb2.o
 +obj-$(CONFIG_OMAP_PIPE3) += phy-omap-pipe3.o
  obj-$(CONFIG_TWL4030_USB)+= phy-twl4030-usb.o
 diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
 similarity index 57%
 rename from drivers/usb/phy/phy-omap-usb3.c
 rename to drivers/phy/phy-omap-pipe3.c
 index 4004f82..ee9a901 100644
 --- a/drivers/usb/phy/phy-omap-usb3.c
 +++ b/drivers/phy/phy-omap-pipe3.c
 @@ -1,5 +1,5 @@
  /*
 - * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
 + * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
   *
   * Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
   * This program is free software; you can redistribute it and/or modify
 @@ -19,7 +19,8 @@
  #include linux/module.h
  #include linux/platform_device.h
  #include linux/slab.h
 -#include linux/usb/omap_usb.h
 +#include linux/phy/omap_pipe3.h
 +#include linux/phy/phy.h
  #include linux/of.h
  #include linux/clk.h
  #include linux/err.h
 @@ -52,17 +53,17 @@
  
  /*
   * This is an Empirical value that works, need to confirm the actual
 - * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
 - * to be correctly reflected in the USB3PHY_PLL_STATUS register.
 + * value required for the PIPE3PHY_PLL_CONFIGURATION2.PLL_IDLE status
 + * to be correctly reflected in the PIPE3PHY_PLL_STATUS register.
   */
  # define PLL_IDLE_TIME  100;
  
 -struct usb_dpll_map {
 +struct pipe3_dpll_map {
   unsigned long rate;
 - struct usb_dpll_params params;
 + struct pipe3_dpll_params params;
  };
  
 -static struct usb_dpll_map dpll_map[] = {
 +static struct pipe3_dpll_map dpll_map[] = {
   {1200, {1250, 5, 4, 20, 0} },   /* 12 MHz */
   {1680, {3125, 20, 4, 20, 0} },  /* 16.8 MHz */
   {1920, {1172, 8, 4, 20, 65537} },   /* 19.2 MHz */
 @@ -71,7 +72,7 @@ static struct usb_dpll_map dpll_map[] = {
   {3840, {3125, 47, 4, 20, 

[PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-09-02 Thread Kishon Vijay Abraham I
Adapted omap-usb3 PHY driver to Generic PHY Framework and moved phy-omap-usb3
driver in drivers/usb/phy to drivers/phy and also renamed the file to
phy-omap-pipe3 since this same driver will be used for SATA PHY and
PCIE PHY.

Signed-off-by: Kishon Vijay Abraham I 
---
 Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
 drivers/phy/Kconfig|   10 +
 drivers/phy/Makefile   |1 +
@@ -52,17 +53,17 @@
  /*
   * This is an Empirical value that works, need to confirm the actual
- * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
- * to be correctly reflected in the USB3PHY_PLL_STATUS register.
+ * value required for the PIPE3PHY_PLL_CONFIGURATION2.PLL_IDLE status
+ * to be correctly reflected in the PIPE3PHY_PLL_STATUS register.
   */
  # define PLL_IDLE_TIME  100;
 .../phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c}   |  206 +++-
 drivers/usb/phy/Kconfig|   11 --
 drivers/usb/phy/Makefile   |1 -
 include/linux/phy/omap_pipe3.h |   52 +
 7 files changed, 177 insertions(+), 109 deletions(-)
 rename drivers/{usb/phy/phy-omap-usb3.c => phy/phy-omap-pipe3.c} (57%)
 create mode 100644 include/linux/phy/omap_pipe3.h

diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
similarity index 57%
rename from drivers/usb/phy/phy-omap-usb3.c
rename to drivers/phy/phy-omap-pipe3.c
index 4004f82..ee9a901 100644
--- a/drivers/usb/phy/phy-omap-usb3.c
+++ b/drivers/phy/phy-omap-pipe3.c
@@ -1,5 +1,5 @@
 /*
- * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
+ * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
  *
  * Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
  * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,8 @@
 #include 
 #include 
 #include 
-#include 
+#include 
+#include 
 #include 
 #include 
 #include 
@@ -52,17 +53,17 @@
 
 /*
  * This is an Empirical value that works, need to confirm the actual
  * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
  * to be correctly reflected in the USB3PHY_PLL_STATUS register.
  */
 # define PLL_IDLE_TIME  100;
 
-struct usb_dpll_map {
+struct pipe3_dpll_map {
unsigned long rate;
-   struct usb_dpll_params params;
+   struct pipe3_dpll_params params;
 };
 
-static struct usb_dpll_map dpll_map[] = {
+static struct pipe3_dpll_map dpll_map[] = {
{1200, {1250, 5, 4, 20, 0} },   /* 12 MHz */
{1680, {3125, 20, 4, 20, 0} },  /* 16.8 MHz */
{1920, {1172, 8, 4, 20, 65537} },   /* 19.2 MHz */
@@ -71,7 +72,7 @@ static struct usb_dpll_map dpll_map[] = {
{3840, {3125, 47, 4, 20, 92843} },  /* 38.4 MHz */
 };
 
-static struct usb_dpll_params *omap_usb3_get_dpll_params(unsigned long rate)
+static struct pipe3_dpll_params *omap_pipe3_get_dpll_params(unsigned long rate)
 {
int i;
 
@@ -83,110 +84,113 @@ static struct usb_dpll_params 
*omap_usb3_get_dpll_params(unsigned long rate)
return 0;
 }
 
-static int omap_usb3_suspend(struct usb_phy *x, int suspend)
+static int omap_pipe3_power_off(struct phy *x)
 {
-   struct omap_usb *phy = phy_to_omapusb(x);
-   int val;
+   struct omap_pipe3 *phy = phy_get_drvdata(x);
+   int val;
  

[PATCH 3/7] drivers: phy: usb3/pipe3: Adapt pipe3 driver to Generic PHY Framework

2013-09-02 Thread Kishon Vijay Abraham I
Adapted omap-usb3 PHY driver to Generic PHY Framework and moved phy-omap-usb3
driver in drivers/usb/phy to drivers/phy and also renamed the file to
phy-omap-pipe3 since this same driver will be used for SATA PHY and
PCIE PHY.

Signed-off-by: Kishon Vijay Abraham I kis...@ti.com
---
 Documentation/devicetree/bindings/usb/usb-phy.txt  |5 +-
 drivers/phy/Kconfig|   10 +
 drivers/phy/Makefile   |1 +
@@ -52,17 +53,17 @@
 /*
  * This is an Empirical value that works, need to confirm the actual
- * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
- * to be correctly reflected in the USB3PHY_PLL_STATUS register.
+ * value required for the PIPE3PHY_PLL_CONFIGURATION2.PLL_IDLE status
+ * to be correctly reflected in the PIPE3PHY_PLL_STATUS register.
  */
 # define PLL_IDLE_TIME  100;
 .../phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c}   |  206 +++-
 drivers/usb/phy/Kconfig|   11 --
 drivers/usb/phy/Makefile   |1 -
 include/linux/phy/omap_pipe3.h |   52 +
 7 files changed, 177 insertions(+), 109 deletions(-)
 rename drivers/{usb/phy/phy-omap-usb3.c = phy/phy-omap-pipe3.c} (57%)
 create mode 100644 include/linux/phy/omap_pipe3.h

diff --git a/drivers/usb/phy/phy-omap-usb3.c b/drivers/phy/phy-omap-pipe3.c
similarity index 57%
rename from drivers/usb/phy/phy-omap-usb3.c
rename to drivers/phy/phy-omap-pipe3.c
index 4004f82..ee9a901 100644
--- a/drivers/usb/phy/phy-omap-usb3.c
+++ b/drivers/phy/phy-omap-pipe3.c
@@ -1,5 +1,5 @@
 /*
- * omap-usb3 - USB PHY, talking to dwc3 controller in OMAP.
+ * omap-pipe3 - PHY driver for SATA, USB and PCIE in OMAP platforms
  *
  * Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com
  * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,8 @@
 #include linux/module.h
 #include linux/platform_device.h
 #include linux/slab.h
-#include linux/usb/omap_usb.h
+#include linux/phy/omap_pipe3.h
+#include linux/phy/phy.h
 #include linux/of.h
 #include linux/clk.h
 #include linux/err.h
@@ -52,17 +53,17 @@
 
 /*
  * This is an Empirical value that works, need to confirm the actual
  * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
  * to be correctly reflected in the USB3PHY_PLL_STATUS register.
  */
 # define PLL_IDLE_TIME  100;
 
-struct usb_dpll_map {
+struct pipe3_dpll_map {
unsigned long rate;
-   struct usb_dpll_params params;
+   struct pipe3_dpll_params params;
 };
 
-static struct usb_dpll_map dpll_map[] = {
+static struct pipe3_dpll_map dpll_map[] = {
{1200, {1250, 5, 4, 20, 0} },   /* 12 MHz */
{1680, {3125, 20, 4, 20, 0} },  /* 16.8 MHz */
{1920, {1172, 8, 4, 20, 65537} },   /* 19.2 MHz */
@@ -71,7 +72,7 @@ static struct usb_dpll_map dpll_map[] = {
{3840, {3125, 47, 4, 20, 92843} },  /* 38.4 MHz */
 };
 
-static struct usb_dpll_params *omap_usb3_get_dpll_params(unsigned long rate)
+static struct pipe3_dpll_params *omap_pipe3_get_dpll_params(unsigned long rate)
 {
int i;
 
@@ -83,110 +84,113 @@ static struct usb_dpll_params 
*omap_usb3_get_dpll_params(unsigned long rate)
return 0;
 }
 
-static int omap_usb3_suspend(struct usb_phy *x, int suspend)
+static int omap_pipe3_power_off(struct phy *x)
 {
-   struct
@@ -52,17 +53,17 @@
 /*
  * This is an Empirical value that works, need to confirm the actual
- * value required for the USB3PHY_PLL_CONFIGURATION2.PLL_IDLE status
- * to be correctly reflected in the USB3PHY_PLL_STATUS register.
+ * value required for the PIPE3PHY_PLL_CONFIGURATION2.PLL_IDLE status
+ * to be correctly reflected in the PIPE3PHY_PLL_STATUS register.
  */
 # define PLL_IDLE_TIME  100;